==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/inputs/OpenZfsFileSystemDiskIopsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.inputs

import com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property iops The total number of SSD IOPS provisioned for the file system.
 * @property mode Specifies whether the number of IOPS for the file system is using the system. Valid values are `AUTOMATIC` and `USER_PROVISIONED`. Default value is `AUTOMATIC`.
 */
public data class OpenZfsFileSystemDiskIopsConfigurationArgs(
    public val iops: Output<Int>? = null,
    public val mode: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs =
        com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs.builder()
            .iops(iops?.applyValue({ args0 -> args0 }))
            .mode(mode?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OpenZfsFileSystemDiskIopsConfigurationArgs].
 */
@PulumiTagMarker
public class OpenZfsFileSystemDiskIopsConfigurationArgsBuilder internal constructor() {
    private var iops: Output<Int>? = null

    private var mode: Output<String>? = null

    /**
     * @param value The total number of SSD IOPS provisioned for the file system.
     */
    @JvmName("nuvheobhkacafcje")
    public suspend fun iops(`value`: Output<Int>) {
        this.iops = value
    }

    /**
     * @param value Specifies whether the number of IOPS for the file system is using the system. Valid values are `AUTOMATIC` and `USER_PROVISIONED`. Default value is `AUTOMATIC`.
     */
    @JvmName("jowqjrymeolhjgpv")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value The total number of SSD IOPS provisioned for the file system.
     */
    @JvmName("rmoesgscusvyrxkl")
    public suspend fun iops(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iops = mapped
    }

    /**
     * @param value Specifies whether the number of IOPS for the file system is using the system. Valid values are `AUTOMATIC` and `USER_PROVISIONED`. Default value is `AUTOMATIC`.
     */
    @JvmName("whlfclkyjswwxtic")
    public suspend fun mode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    internal fun build(): OpenZfsFileSystemDiskIopsConfigurationArgs =
        OpenZfsFileSystemDiskIopsConfigurationArgs(
            iops = iops,
            mode = mode,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/inputs/OpenZfsFileSystemDiskIopsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.inputs

import com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property iops The total number of SSD IOPS provisioned for the file system.
 * @property mode Specifies whether the number of IOPS for the file system is using the system. Valid values are `AUTOMATIC` and `USER_PROVISIONED`. Default value is `AUTOMATIC`.
 */
public data class OpenZfsFileSystemDiskIopsConfigurationArgs(
    public val iops: Output<Int>? = null,
    public val mode: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs =
        com.pulumi.aws.fsx.inputs.OpenZfsFileSystemDiskIopsConfigurationArgs.builder()
            .iops(iops?.applyValue({ args0 -> args0 }))
            .mode(mode?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OpenZfsFileSystemDiskIopsConfigurationArgs].
 */
@PulumiTagMarker
public class OpenZfsFileSystemDiskIopsConfigurationArgsBuilder internal constructor() {
    private var iops: Output<Int>? = null

    private var mode: Output<String>? = null

    /**
     * @param value The total number of SSD IOPS provisioned for the file system.
     */
    @JvmName("lbnureaswerlhyeb")
    public suspend fun iops(`value`: Output<Int>) {
        this.iops = value
    }

    /**
     * @param value Specifies whether the number of IOPS for the file system is using the system. Valid values are `AUTOMATIC` and `USER_PROVISIONED`. Default value is `AUTOMATIC`.
     */
    @JvmName("fflqebeeipntisvy")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value The total number of SSD IOPS provisioned for the file system.
     */
    @JvmName("fwmfivwdvorpllkv")
    public suspend fun iops(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iops = mapped
    }

    /**
     * @param value Specifies whether the number of IOPS for the file system is using the system. Valid values are `AUTOMATIC` and `USER_PROVISIONED`. Default value is `AUTOMATIC`.
     */
    @JvmName("kyonenctagjwbdua")
    public suspend fun mode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    internal fun build(): OpenZfsFileSystemDiskIopsConfigurationArgs =
        OpenZfsFileSystemDiskIopsConfigurationArgs(
            iops = iops,
            mode = mode,
        )
}
